@@ -50,6 +50,10 @@
 #include <libgames-support/games-atk-utils.h>
 #endif
 
+#if GLIB_CHECK_VERSION (2, 25, 15)
+#include <libgames-support/games-settings.h>
+#endif
+
 #ifdef HAVE_CLUTTER
 #include "ar-clutter-embed.h"
 #include "ar-style.h"
@@ -103,6 +107,9 @@
 #define LEAVE_FULLSCREEN_BUTTON
 #endif
 
+#define AR_SETTINGS_PATH_PREFIX "/org/gnome/solitaire/"
+#define AR_SETTINGS_WINDOW_STATE_PATH AR_SETTINGS_PATH_PREFIX "window-state/"
+
 enum
 {
   ACTION_UNDO_MOVE,
@@ -2117,11 +2124,13 @@ aisleriot_window_state_event (GtkWidget *widget,
     set_fullscreen_button_active (window);
 
 #ifndef HAVE_HILDON
+#if !GTK_CHECK_VERSION (2, 91, 0)
 #if GTK_CHECK_VERSION (2, 11, 0)
     gtk_statusbar_set_has_resize_grip (priv->statusbar, !is_maximised && !is_fullscreen);
 #else
     gtk_statusbar_set_has_resize_grip (priv->statusbar, FALSE);
 #endif
+#endif /* GTK < 3.0 */
 #endif /* !HAVE_HILDON */
   }
 
@@ -2562,11 +2571,15 @@ aisleriot_window_init (AisleriotWindow *window)
                     G_CALLBACK (board_status_message_cb), window);
 #endif
 
+#if GTK_CHECK_VERSION (2, 91, 0)
+  gtk_window_set_has_resize_grip (GTK_WINDOW (window), TRUE);
+#else
 #if GTK_CHECK_VERSION (2, 11, 0)
   gtk_statusbar_set_has_resize_grip (priv->statusbar, TRUE);
 #else
   gtk_statusbar_set_has_resize_grip (priv->statusbar, FALSE);
 #endif
+#endif /* GTK 3.0 */
 
 #if GTK_CHECK_VERSION (2, 19, 1)
   statusbar_hbox = gtk_statusbar_get_message_area (statusbar);
@@ -2762,7 +2775,11 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_window_set_default_size (GTK_WINDOW (window), MIN_WIDTH, MIN_HEIGHT);
 
   /* Restore window state */
+#if GLIB_CHECK_VERSION (2, 25, 15)
+  games_settings_bind_window_state (AR_SETTINGS_WINDOW_STATE_PATH, GTK_WINDOW (window));
+#else
   games_conf_add_window (GTK_WINDOW (window), NULL);
+#endif
 
   /* Initial focus is in the board */
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
