@@ -11,8 +11,7 @@ from glchess.defaults import *
 
 import glchess.scene
 import texture
-import new_models
-builtin_models = new_models
+import models
 
 PIECE_MOVE_SPEED    = 50.0 # FIXME: Define units
 BOARD_ROTATION_TIME = 0.8
@@ -25,6 +24,22 @@ BOARD_INNER_WIDTH = (SQUARE_WIDTH * 8.0)
 BOARD_OUTER_WIDTH = (BOARD_INNER_WIDTH + BOARD_BORDER * 2.0)
 OFFSET            = (BOARD_OUTER_WIDTH * 0.5)
 
+def parse_colour(colour):
+    assert colour.startswith('#')
+    assert len(colour) == 7
+    r = int(colour[1:3], 16) / 255.
+    g = int(colour[3:5], 16) / 255.
+    b = int(colour[5:7], 16) / 255.
+    return (r, g, b)
+
+def blend_colour(colour_a, colour_b, alpha):
+    a = parse_colour(colour_a)
+    b = parse_colour(colour_b)
+    r = a[0] * alpha + b[0] * (1 - alpha)
+    g = a[1] * alpha + b[1] * (1 - alpha)
+    b = a[2] * alpha + b[2] * (1 - alpha)
+    return (r, g, b)
+
 LIGHT_AMBIENT_COLOUR  = (0.4, 0.4, 0.4, 1.0)
 LIGHT_DIFFUSE_COLOUR  = (0.7, 0.7, 0.7, 1.0)
 LIGHT_SPECULAR_COLOUR = (1.0, 1.0, 1.0, 1.0)
@@ -34,18 +49,18 @@ BOARD_DIFFUSE   = (0.8, 0.8, 0.8, 1.0)
 BOARD_SPECULAR  = (1.0, 1.0, 1.0, 1.0)
 BOARD_SHININESS = 128.0
 
-BACKGROUND_COLOUR    = (0.53, 0.63, 0.75, 0.0)
-BORDER_COLOUR        = (0.72, 0.33, 0.0)
-BLACK_SQUARE_COLOURS = {None:                               (0.8, 0.8, 0.8),
-                        glchess.scene.HIGHLIGHT_SELECTED:   (0.3, 1.0, 0.3),
-                        glchess.scene.HIGHLIGHT_CAN_MOVE:   (0.3, 0.3, 1.0),
-                        glchess.scene.HIGHLIGHT_THREATENED: (1.0, 0.8, 0.8),
-                        glchess.scene.HIGHLIGHT_CAN_TAKE:   (1.0, 0.3, 0.3)}
-WHITE_SQUARE_COLOURS = {None:                               (1.0, 1.0, 1.0),
-                        glchess.scene.HIGHLIGHT_SELECTED:   (0.2, 1.0, 0.0),
-                        glchess.scene.HIGHLIGHT_CAN_MOVE:   (0.2, 0.2, 0.8),
-                        glchess.scene.HIGHLIGHT_THREATENED: (1.0, 0.8, 0.8),
-                        glchess.scene.HIGHLIGHT_CAN_TAKE:   (1.0, 0.2, 0.2)}
+BORDER_COLOUR        = parse_colour('#2e3436')
+NUMBERING_COLOUR     = parse_colour('#888a85')
+BLACK_SQUARE_COLOURS = {None:                               parse_colour('#babdb6'),
+                        glchess.scene.HIGHLIGHT_SELECTED:   parse_colour('#73d216'),
+                        glchess.scene.HIGHLIGHT_CAN_MOVE:   parse_colour('#3465a4'),
+                        glchess.scene.HIGHLIGHT_THREATENED: blend_colour('#af0000', '#babdb6', 0.2),
+                        glchess.scene.HIGHLIGHT_CAN_TAKE:   blend_colour('#af0000', '#babdb6', 0.8)}
+WHITE_SQUARE_COLOURS = {None:                               parse_colour('#eeeeec'),
+                        glchess.scene.HIGHLIGHT_SELECTED:   parse_colour('#8ae234'),
+                        glchess.scene.HIGHLIGHT_CAN_MOVE:   parse_colour('#204a87'),
+                        glchess.scene.HIGHLIGHT_THREATENED: blend_colour('#cc0000', '#eeeeec', 0.2),
+                        glchess.scene.HIGHLIGHT_CAN_TAKE:   blend_colour('#cc0000', '#eeeeec', 0.8)}
 
 import math
 def accFrustum(left, right, bottom, top,
@@ -78,24 +93,6 @@ def accPerspective(fovy, aspect,
 class ChessPiece(glchess.scene.ChessPiece):
     """
     """    
-    scene     = None
-    
-    # The piece to render
-    chessSet  = None
-    name      = None
-    
-    # The algebraic square location
-    location  = ''
-    
-    # The OpenGL co-ordinate location
-    pos       = None
-    targetPos = None
-    
-    # Is the piece moving?
-    moving    = False
-    
-    # Delete once moved?
-    delete    = False
     
     def __init__(self, scene, chessSet, name, location, feedback):
         """
@@ -106,6 +103,9 @@ class ChessPiece(glchess.scene.ChessPiece):
         self.name = name
         self.location = location
         self.pos = self.scene._coordToLocation(location)
+        self.targetPos = None  # Position moving to
+        self.moving    = False # Is the piece moving?
+        self.delete    = False # Delete once moved?
 
     def move(self, coord, delete, animate = True):
         """Extends glchess.scene.ChessPiece"""
@@ -186,58 +186,43 @@ class ChessPiece(glchess.scene.ChessPiece):
 class Scene(glchess.scene.Scene):
     """
     """
-    # The viewport dimensions
-    viewportWidth    = 0
-    viewportHeight   = 0
-    viewportAspect   = 1.0
-    
-    animating        = False
-    
-    # Loading screen properties
-    throbberEnabled  = False
-    throbberAngle    = 0.0
-    
-    # The scene light position
-    lightPos         = None
-
-    # The board angle in degrees
-    boardAngle       = 0.0
-    oldBoardAngle    = 0.0
-    targetBoardAngle = 0.0
-    
-    # OpenGL display list for the board and a flag to regenerate it
-    boardList        = None
-    regenerateBoard  = False
-    
-    # Texture objects for the board
-    whiteTexture     = None
-    blackTexture     = None
-
-    # ...
-    pieces           = None
-    chessSets        = None
-    piecesMoving     = False
-    
-    # Dictionary of co-ordinates to highlight
-    highlights       = None
-    
-    _animationQueue  = []
-    
-    jitters = ((0.0, 0.0),)
-
-    showNumbering = False
-    numberingTexture = None
 
     def __init__(self, feedback):
         """Constructor for an OpenGL scene"""
         self.feedback = feedback
-        self.lightPos = [100.0, 100.0, 100.0, 1.0]
+        self.lightPos = [100.0, 100.0, 100.0, 1.0] # The scene light position
         self.pieces = []
         self.highlights = {}
         self._animationQueue = []
+        self.animating = False
+        self.piecesMoving = False
+
+        # The viewport dimensions
+        self.viewportWidth    = 0
+        self.viewportHeight   = 0
+        self.viewportAspect   = 1.0
+    
+        # Loading screen properties
+        self.throbberEnabled  = False
+        self.throbberAngle    = 0.0
+    
+        # The board angle in degrees
+        self.boardAngle       = 0.0
+        self.oldBoardAngle    = 0.0
+        self.targetBoardAngle = 0.0
+    
+        # OpenGL display list for the board and a flag to regenerate it
+        self.boardList        = None
+        self.regenerateBoard  = False
+    
+        self.jitters = ((0.0, 0.0),)
+
+        self.showNumbering = False
+        self.numberingTexture = None
         
-        self.chessSets = {'white': builtin_models.WhiteBuiltinSet(), 'black': builtin_models.BlackBuiltinSet()}
+        self.chessSets = {'white': models.WhiteBuiltinSet(), 'black': models.BlackBuiltinSet()}
         
+        # Texture objects for the board
         self.whiteTexture = texture.Texture(os.path.join(TEXTURE_DIR, 'board.png'),
                                             ambient = BOARD_AMBIENT, diffuse = BOARD_DIFFUSE,
                                             specular = BOARD_SPECULAR, shininess = BOARD_SHININESS)
@@ -311,7 +296,7 @@ class Scene(glchess.scene.Scene):
         glViewport(0, 0, self.viewportWidth, self.viewportHeight)
         self.feedback.onRedraw()
 
-    def setBoardRotation(self, angle, animate = True):
+    def setBoardRotation(self, angle, faceToFace = False, animate = True):
         """Set the rotation on the board.
         
         'angle' is the angle the board should be drawn at in degress (float, [0.0, 360.0]).
@@ -339,15 +324,15 @@ class Scene(glchess.scene.Scene):
             self.animating = False
         return self.animating
 
-    def render(self):
+    def render(self, background_colour):
         """Render the scene.
         
         This requires an OpenGL context.
         """
-        glClearColor(*BACKGROUND_COLOUR)
+        glClearColor(background_colour[0], background_colour[1], background_colour[2], 1.0)
         if len(self.jitters) > 1:
             glClear(GL_ACCUM_BUFFER_BIT)
-        
+
         glLightfv(GL_LIGHT0, GL_AMBIENT, LIGHT_AMBIENT_COLOUR)
         glLightfv(GL_LIGHT0, GL_DIFFUSE, LIGHT_DIFFUSE_COLOUR)
         glLightfv(GL_LIGHT0, GL_SPECULAR, LIGHT_SPECULAR_COLOUR)
@@ -400,7 +385,7 @@ class Scene(glchess.scene.Scene):
 
         if len(self.jitters) > 1:
             glAccum(GL_RETURN, 1)
-            
+
     def getSquare(self, x, y):
         """Find the chess square at a given 2D location.
         
@@ -627,7 +612,7 @@ class Scene(glchess.scene.Scene):
 
     def transformCamera(self):
         """Perform the camera matrix transformation"""
-        gluLookAt(0.0, 90.0, 45.0,
+        gluLookAt(0.0, 80.0, 40.0,
                   0.0,  0.0, 5.0,
                   0.0,  1.0,  0.0)
                   
@@ -716,9 +701,11 @@ class Scene(glchess.scene.Scene):
         glNormal3f(0.0, 1.0, 0.0)
         glDisable(GL_DEPTH_TEST)
         glEnable(GL_TEXTURE_2D)
+        glEnable(GL_COLOR_MATERIAL)        
         glEnable(GL_BLEND)
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
         glBindTexture(GL_TEXTURE_2D, self.numberingTexture)
+        glColor3f(*NUMBERING_COLOUR)
 
         for i in xrange(8):
             drawLabel(leftOffset, -offset, i + 8)
@@ -730,6 +717,7 @@ class Scene(glchess.scene.Scene):
 
         glEnable(GL_DEPTH_TEST)
         glDisable(GL_BLEND)
+        glDisable(GL_COLOR_MATERIAL)
         glDisable(GL_TEXTURE_2D)
 
     def drawBoard(self):
