@@ -66,9 +66,6 @@ static gboolean ready_to_advance_player;
 #define DIE_SELECTED_PIXMAP  (NUMBER_OF_PIXMAPS-1)
 #define SCORES_CATEGORY (game_type == GAME_KISMET ? "Colors" : NULL)
 
-#define DEFAULT_WIDTH 640
-#define DEFAULT_HEIGHT 480
-
 static char *dicefiles[NUMBER_OF_PIXMAPS] = { "gnome-dice-1.svg",
   "gnome-dice-2.svg",
   "gnome-dice-3.svg",
@@ -101,7 +98,7 @@ static gchar *game_type_string = NULL;
 static gint   test_computer_play = 0;
 gint NUM_TRIALS = 0;
 
-const static GOptionEntry yahtzee_options[] = {
+static const GOptionEntry yahtzee_options[] = {
   {"delay", 'd', 0, G_OPTION_ARG_NONE, &DoDelay,
    N_("Delay computer moves"), NULL},
   {"thoughts", 't', 0, G_OPTION_ARG_NONE, &DisplayComputerThoughts,
@@ -257,7 +254,7 @@ do_computer_turns (void)
 /* Show the current score and prompt for current player state */
 
 void
-DisplayCurrentPlayer() {
+DisplayCurrentPlayer(void) {
   ShowoffPlayer (ScoreList, CurrentPlayer, 1);
 
   if (players[CurrentPlayer].name) {
@@ -436,7 +433,7 @@ key_press (GtkWidget * widget, GdkEventKey * event, gpointer data)
 {
   gint offset;
 
-  offset = event->keyval - GDK_1;
+  offset = event->keyval - GDK_KEY_1;
 
   if ((offset < 0) || (offset >= NUMBER_OF_DICE)) {
     return FALSE;
@@ -674,8 +671,15 @@ LoadDicePixmaps (void)
           g_file_test (path_kismet, G_FILE_TEST_EXISTS)) {
 
       for (j = 0; j < NUMBER_OF_DICE; j++) {
-        dicePixmaps[j][i][GAME_YAHTZEE] = gtk_image_new_from_file (path);
-        dicePixmaps[j][i][GAME_KISMET] = gtk_image_new_from_file (path_kismet);
+        GdkPixbuf *pixbuf;
+
+        pixbuf = gdk_pixbuf_new_from_file_at_size (path, 60, 60, NULL);
+        dicePixmaps[j][i][GAME_YAHTZEE] = gtk_image_new_from_pixbuf (pixbuf);
+        g_object_unref (pixbuf);
+
+        pixbuf = gdk_pixbuf_new_from_file_at_size (path_kismet, 60, 60, NULL);
+        dicePixmaps[j][i][GAME_KISMET] = gtk_image_new_from_pixbuf (pixbuf);
+        g_object_unref (pixbuf);
       }
 
     } /* FIXME: What happens if the file isn't found. */
@@ -769,7 +773,6 @@ GyahtzeeCreateMainWindow (void)
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _(appName));
 
-  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
   games_conf_add_window (GTK_WINDOW (window), NULL);
 
   g_signal_connect (G_OBJECT (window), "delete_event",
@@ -780,7 +783,6 @@ GyahtzeeCreateMainWindow (void)
   statusbar = gtk_statusbar_new ();
   ui_manager = gtk_ui_manager_new ();
 
-  gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), FALSE);
   games_stock_prepare_for_statusbar_tooltips (ui_manager, statusbar);
 
 	/*---- Menus ----*/
@@ -821,7 +823,7 @@ GyahtzeeCreateMainWindow (void)
   gtk_widget_show (GTK_WIDGET (mbutton));
 
   toolbar = gtk_toolbar_new ();
-  gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (toolbar),
 			       GTK_ORIENTATION_VERTICAL);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
   gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
@@ -874,7 +876,9 @@ main (int argc, char *argv[])
   if (!games_runtime_init ("gtali"))
     return 1;
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   /* Reset all yahtzee variables before parsing args */
   YahtzeeInit ();
@@ -906,10 +910,10 @@ main (int argc, char *argv[])
           game_type = game_type_from_string(game_type_string);
       g_message("In test computer play section - Using %d trials for simulation", NUM_TRIALS);
       for (ii = 0; ii < test_computer_play; ii++) {
+          int num_rolls = 0;
           NumberOfHumans = 0;
           NumberOfComputers = 1;
           NewGame ();
-          int num_rolls = 0;
 
           while (!GameIsOver() && num_rolls < 100) {
               ComputerRolling (CurrentPlayer);
