@@ -27,6 +27,9 @@
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
+/* For gdkcairo */
+#include <gdk/gdk.h>
+
 #ifdef HAVE_RSVG
 #include <librsvg/rsvg.h>
 #include <librsvg/rsvg-cairo.h>
@@ -121,6 +124,56 @@ games_preimage_render (GamesPreimage * preimage, gint width, gint height)
   return pixbuf;
 }
 
+/**
+ * games_preimage_render_cairo:
+ * @preimage:
+ * @cr:
+ * @width: the desired width
+ * @height: the desired height
+ *
+ * Renders from @preimage's image at the specified
+ * @width and @height to @cr.
+*/
+void
+games_preimage_render_cairo (GamesPreimage * preimage,
+                             cairo_t *cr,
+                             gint width,
+                             gint height)
+{
+  g_return_if_fail (width > 0 && height > 0);
+  g_return_if_fail (preimage != NULL);
+
+#ifdef HAVE_RSVG
+  if (preimage->scalable) {     /* Render vector image */
+    games_preimage_render_cairo_sub (preimage,
+                                     cr,
+                                     NULL,
+                                     width,
+                                     height,
+                                     0.0, 0.0,
+                                     ((double) width) /
+                                     ((double) preimage->width),
+                                     ((double) height) /
+                                     ((double) preimage->height));
+  } else
+#endif /* HAVE_RSVG */
+  {
+    GdkPixbuf *pixbuf;
+
+    /* FIXMEchpe: we don't really need this fallback anymore */
+    /* Render raster image */
+    pixbuf = gdk_pixbuf_scale_simple (preimage->pixbuf,
+                                      width, height, GDK_INTERP_BILINEAR);
+
+    cairo_save (cr);
+    gdk_cairo_set_source_pixbuf (cr, pixbuf, 0, 0);
+    cairo_paint (cr);
+    cairo_restore (cr);
+
+    g_object_unref (pixbuf);
+  }
+}
+
 #ifdef HAVE_RSVG
 
 /* This routine is copied from librsvg:
@@ -157,6 +210,58 @@ cairo_pixels_to_pixbuf (guint8 * pixels, int rowstride, int height)
   }
 }
 
+/**
+ * games_preimage_render_cairo_sub:
+ * @preimage:
+ * @cr:
+ * @node: a SVG node ID (starting with "#"), or %NULL
+ * @width: the width of the clip region
+ * @height: the height of the clip region
+ * @xoffset: the x offset of the clip region
+ * @yoffset: the y offset of the clip region
+ * @xzoom: the x zoom factor
+ * @yzoom: the y zoom factor
+ *
+ * Creates a #GdkPixbuf with the dimensions @width by @height,
+ * and renders the subimage of @preimage specified by @node to it,
+ * transformed by @xzoom, @yzoom and offset by @xoffset and @yoffset,
+ * clipped to @width and @height.
+ * If @node is NULL, the whole image is rendered into tha clip region.
+ *
+ * Returns: %TRUE, of %FALSE if there was an error or @preimage
+ * isn't a scalable SVG image
+ */
+void
+games_preimage_render_cairo_sub (GamesPreimage * preimage,
+                                 cairo_t *cr,
+                                 const char *node,
+                                 int width,
+                                 int height,
+                                 double xoffset,
+                                 double yoffset,
+                                 double xzoom,
+                                 double yzoom)
+{
+  cairo_matrix_t matrix;
+
+  if (!preimage->scalable)
+    return;
+
+  if (preimage->font_options) {
+    cairo_set_antialias (cr, cairo_font_options_get_antialias (preimage->font_options));
+
+    cairo_set_font_options (cr, preimage->font_options);
+  }
+
+  cairo_matrix_init_identity (&matrix);
+  cairo_matrix_scale (&matrix, xzoom, yzoom);
+  cairo_matrix_translate (&matrix, xoffset, yoffset);
+
+  cairo_set_matrix (cr, &matrix);
+
+  rsvg_handle_render_cairo_sub (preimage->rsvg_handle, cr, node);
+}
+
 /**
  * games_preimage_render_sub:
  * @preimage:
@@ -185,12 +290,10 @@ games_preimage_render_sub (GamesPreimage * preimage,
                            double xoffset,
                            double yoffset, double xzoom, double yzoom)
 {
-  GdkPixbuf *pixbuf = NULL;
   int rowstride;
   guint8 *data;
   cairo_surface_t *surface;
-  cairo_t *cx;
-  cairo_matrix_t matrix;
+  cairo_t *cr;
 
   if (!preimage->scalable)
     return NULL;
@@ -208,47 +311,20 @@ games_preimage_render_sub (GamesPreimage * preimage,
   surface = cairo_image_surface_create_for_data (data,
                                                  CAIRO_FORMAT_ARGB32,
                                                  width, height, rowstride);
-  if (cairo_surface_status (surface) != CAIRO_STATUS_SUCCESS) {
-    g_free (data);
-    return NULL;
-  }
-
-  cx = cairo_create (surface);
-
-  if (preimage->font_options) {
-    cairo_set_antialias (cx, cairo_font_options_get_antialias (preimage->font_options));
-
-    cairo_set_font_options (cx, preimage->font_options);
-  }
-
-  cairo_matrix_init_identity (&matrix);
-  cairo_matrix_scale (&matrix, xzoom, yzoom);
-  cairo_matrix_translate (&matrix, xoffset, yoffset);
-
-  cairo_set_matrix (cx, &matrix);
-
-  rsvg_handle_render_cairo_sub (preimage->rsvg_handle, cx, node);
-
+  cr = cairo_create (surface);
+  games_preimage_render_cairo_sub (preimage, cr, node, width, height,
+                                   xoffset, yoffset, xzoom, yzoom);
+  cairo_destroy (cr);
+  cairo_surface_destroy (surface);
   cairo_pixels_to_pixbuf (data, rowstride, height);
 
-  if (cairo_status (cx) == CAIRO_STATUS_SUCCESS) {
-    pixbuf = gdk_pixbuf_new_from_data (data,
-                                       GDK_COLORSPACE_RGB,
-                                       TRUE,
-                                       8,
-                                       width, height,
-                                       rowstride,
-                                       (GdkPixbufDestroyNotify) g_free, NULL);
-    data = NULL;
-  }
-
-  cairo_destroy (cx);
-
-  cairo_surface_destroy (surface);
-
-  g_free (data);
-
-  return pixbuf;
+  return gdk_pixbuf_new_from_data (data,
+                                   GDK_COLORSPACE_RGB,
+                                   TRUE,
+                                   8,
+                                   width, height,
+                                   rowstride,
+                                   (GdkPixbufDestroyNotify) g_free, data);
 }
 
 #endif /* HAVE_RSVG */
